@@ -14,7 +14,7 @@ import shutil
 import json
 import logging
 import sqlite3
-from typing import List, Dict, Optional
+from typing import List, Dict, Optional, Union
 from datetime import datetime as dt
 
 # Mapping des champs possibles d'un logging avec les type SQLite3
@@ -491,9 +491,9 @@ class BaseArtimon(HandlerBase):
     environment : Optional[str]
         nom facultatif de l'environnement (si non renseigné sera complété 
         automatiquement par Artimon).
-    label : Optional[dict]
+    labels : Optional[Dict[str, Union[float, int, str]]]
         label en complément de la métrique (comme l'environnement, la version,
-        etc.)
+        etc.). Dans Artimon les labels sont références aux tags.
     format : List[str]
         liste des attributs du LogRecord qu'on souhaite récupérer et 
         stocker. Liste des attributs de LogRecord présentés à l'URL :
@@ -546,14 +546,14 @@ class BaseArtimon(HandlerBase):
         producer: str,
         hostname: Optional[str]=None,
         environment: Optional[str]=None,
-        label: Optional[Dict[str, str]]=None,
+        labels: Optional[Dict[str, Union[float, int, str]]]=None,
         format: List[str]=['name', 'msg'],
     ) -> None:
         super().__init__(format = format)
         self.producer = producer
         self.hostname = hostname
         self.environment = environment
-        self.label = label
+        self.labels = labels
 
     def parser(self, record: logging.LogRecord) -> str:
         name = record.name
@@ -565,10 +565,13 @@ class BaseArtimon(HandlerBase):
         if 'msg' in self.format:
             format.remove('msg')
         tags = {kk: record.__dict__[kk] for kk in format}
-        if self.hostname is not None:
+        if self.hostname:
             tags['hostname'] = self.hostname
-        if self.environment is not None:
+        if self.environment:
             tags['environment'] = self.environnement
+        if self.labels:
+            for kk in self.labels:
+                tags[kk] = self.labels[kk]
         message = [
             dict(
                 i=dict(p=self.producer),
@@ -577,8 +580,6 @@ class BaseArtimon(HandlerBase):
                 c=dict(t=int(round(record.created*1000)))
             )
         ]
-        if self.label:
-            message[0]['l'] = self.label
         return json.dumps(message)
 
 class ArtimonAPIHandler(BaseArtimon):
@@ -601,9 +602,9 @@ class ArtimonAPIHandler(BaseArtimon):
     environment : Optional[str]
         nom facultatif de l'environnement (si non renseigné sera complété 
         automatiquement par Artimon).
-    label : Optional[dict]
+    labels : Optional[Dict[str, Union[float, int, str]]]
         label en complément de la métrique (comme l'environnement, la version,
-        etc.)
+        etc.). Dans Artimon les labels sont références aux tags.
     format : List[str]
         liste des attributs du LogRecord qu'on souhaite récupérer et stocker. 
         Liste des attributs de LogRecord présentés à l'URL :
@@ -704,7 +705,7 @@ class ArtimonAPIHandler(BaseArtimon):
         port: str='9023',
         hostname: Optional[str]=None,
         environment: Optional[str]=None,
-        label: Optional[Dict[str, str]]=None,
+        labels: Optional[Dict[str, Union[float, int, str]]]=None,
         format: List[str]=['name', 'msg']
     ) -> None:
         try:
@@ -728,13 +729,11 @@ class ArtimonAPIHandler(BaseArtimon):
             producer=producer,
             hostname=hostname,
             environment=environment,
-            label=label
+            labels=labels
         )
         self.host = host
         self.port = port
-        self.url = (
-            f"http://{self.host}:{self.port}/metrics"
-        )
+        self.url = f"http://{self.host}:{self.port}/metrics"
 
     def emit(self, record: logging.LogRecord) -> None:
         self._asctime(record)
@@ -779,9 +778,9 @@ class ArtimonLocalHandler(BaseArtimon):
     environment : Optional[str]
         nom facultatif de l'environnement (si non renseigné sera complété 
         automatiquement par Artimon).
-    label : Optional[dict]
+    labels : Optional[Dict[str, Union[float, int, str]]]
         label en complément de la métrique (comme l'environnement, la version,
-        etc.)
+        etc.). Dans Artimon les labels sont références aux tags.
     time_life : int (**deprecated**)
         nombre de jour d'activité du fichier récoltant les métriques. Le
         collecteur Artimon supprime automatiquement les fichiers qui ont 7 
@@ -890,7 +889,7 @@ class ArtimonLocalHandler(BaseArtimon):
         path: str='/var/run/artimonV2',
         hostname: Optional[str]=None,
         environment: Optional[str]=None,
-        label: Optional[Dict[str, str]]=None,
+        labels: Optional[Dict[str, Union[float, int, str]]]=None,
         format: List[str]=['name', 'msg']
     ) -> None:
         if 'message' in format:
@@ -903,7 +902,7 @@ class ArtimonLocalHandler(BaseArtimon):
             producer=producer,
             hostname=hostname,
             environment=environment,
-            label=label
+            labels=labels
         )
         self.path = path
         if not os.path.exists(path):
