@@ -255,16 +255,16 @@ class BaseEnvironnement(BaseEstimator):
             paramètres attachés à Pickle.load(file, **kargs_load) si path ou 
             Pickle.loads(data, **kargs_load) si bytes.
         """
-        mother_classes = self.__class__.__bases__
+        # mother_classes = self.__class__.__bases__
         # dans le cadre d'un apprentissage distribué on ne garantie pas que le
         # build soit présent (simplifie l'interfaçage entre DSTK et DDP).
-        if DDP not in mother_classes and not is_dist_avail_and_initialized():
-            if not hasattr(self, 'build'):
-                raise NotImplementedError(
-                    "Le modèle PyTorch n'a pas de méthode build (réf. doc de "
-                    "la classe)."
-                )
-            self.build()
+        # if DDP not in mother_classes and not is_dist_avail_and_initialized():
+        if not hasattr(self, 'build'):
+            raise NotImplementedError(
+                "Le modèle PyTorch n'a pas de méthode build (réf. doc de "
+                "la classe)."
+            )
+        self.build()
         if isinstance(path_or_bytes, str):
             _, state_dict, state_optimizer, state_attribut = pkl.load(
                 file = open(path_or_bytes, 'br'),
