@@ -21,7 +21,6 @@ from torch import Tensor, device as torch_device
 from torch.cuda.amp import GradScaler
 from tqdm import tqdm
 
-from dstk.pytorch import is_main_process
 from dstk.utils.meta_interface import SuperclassDocstring
 from dstk.utils.errors import TrainError
 
@@ -478,12 +477,15 @@ class CallbackHandler(CallbackInterface):
             0 if cc.__class__.__name__=='ProgressBarCallback' else ii
             for ii, cc in zip(range(1, len(callbacks)+1), callbacks)
         ]
-        callbacks = list(
-            map(
-                lambda x: x[1],
-                sorted(zip(order, callbacks), key=lambda x: x[0])
+        if callbacks:
+            callbacks = list(
+                map(
+                    lambda x: x[1],
+                    sorted(zip(order, callbacks), key=lambda x: x[0])
+                )
             )
-        )
+        else:
+            callbacks = [CallbackInterface()]
         self.callbacks = callbacks
 
     def copy(self):
@@ -669,6 +671,10 @@ class PrintCallback(CallbackInterface):
     Callback simple permettant d'afficher la performance du modèle en cours 
     d'apprentissage après l'évaliation.
     """
+    def __post_init__(self):
+        from dstk.pytorch._utils_distrib import is_main_process
+        self.is_main = is_main_process
+
     def end_eval(
         self,
         model: PyTorchEstimators,
@@ -678,7 +684,7 @@ class PrintCallback(CallbackInterface):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process():
+        if self.is_main():
             print(
                 f"\nid : {state.id_process}\n"
                 f"Epoch : {state.n_epoch+1}/{state.nb_epoch}, "
@@ -728,6 +734,8 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
     nb_backup: Optional[int] = None
 
     def __post_init__(self):
+        from dstk.pytorch._utils_distrib import is_main_process
+        self.is_main = is_main_process
         if is_main_process() and not os.path.exists(self.path_backup):
             os.makedirs(self.path_backup)
 
@@ -740,7 +748,7 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and state.n_iter % self.n_iter == 0:
+        if self.is_main() and state.n_iter % self.n_iter == 0:
             pkl.dump(
                 [
                     model.state_dict(),
@@ -753,7 +761,7 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
                     "wb"
                 )
             )
-        if is_main_process() and self.nb_backup:
+        if self.is_main() and self.nb_backup:
             files = sorted(
                 list(
                     filter(
@@ -779,7 +787,7 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.erase_folder:
+        if self.is_main() and self.erase_folder:
             files = list(
                 filter(
                     lambda x: (
@@ -803,7 +811,7 @@ class Backup(CallbackInterface, metaclass=SuperclassDocstring):
         **kwargs
     ) -> None:
         if (
-            is_main_process()
+            self.is_main()
             and isinstance(exception, KeyboardInterrupt)
             and self.erase_folder
         ):
@@ -853,6 +861,8 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
     verbose: bool = False
 
     def __post_init__(self):
+        from dstk.pytorch._utils_distrib import is_main_process
+        self.is_main = is_main_process
         self.old_res_loss = (np.inf if self.minimize else -np.inf)
         self.iter_stop: int = 0
         self.best_epoch: int = 0
@@ -876,7 +886,7 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
             if self.minimize else 
             res_loss > self.old_res_loss
         ):
-            if is_main_process() and self.verbose:
+            if self.is_main() and self.verbose:
                 print(
                     "\nGain de performance époque/itération : "
                     f"{state.n_epoch+1}/{state.n_iter+1} ;\n"
@@ -890,7 +900,7 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
             self.best_iter = state.n_iter
             if self.path_early_stopping is None:
                 self.state_dict = model._extract_state(model)
-            elif is_main_process():
+            elif self.is_main():
                 model.save_model(
                     f"{self.path_early_stopping}/{state.id_process}.model"
                 )
@@ -915,7 +925,7 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.verbose:
+        if self.is_main() and self.verbose:
             print(
                 f"\nMeilleure époque/iteration : {self.best_epoch+1}/"
                 f"{self.best_iter+1}\n"
@@ -931,7 +941,7 @@ class EarlyStoppingCallback(CallbackInterface, metaclass=SuperclassDocstring):
             model.load_weights(
                 f"{self.path_early_stopping}/{state.id_process}.model"
             )
-            if is_main_process():
+            if self.is_main():
                 os.remove(
                     f"{self.path_early_stopping}/{state.id_process}.model"
                 )
@@ -996,6 +1006,8 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
     verbose: bool = False
 
     def __post_init__(self):
+        from dstk.pytorch._utils_distrib import is_main_process
+        self.is_main = is_main_process
         if self.lr_scheduler.__name__ == "ReduceLROnPlateau" and self.by_step:
             raise AttributeError(
                 "Le lr_scheduler est le ReduceLROnPlateau et ne peut pas "
@@ -1020,13 +1032,13 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
             **self.scheduler_kwargs
         )
         if self.state_dict:
-            if is_main_process():
+            if self.is_main():
                 print(
                     "Chargement de paramètres du Learning Rate Scheduler :"
                 )
                 print(self.state_dict)
             self.scheduler.load_state_dict(self.state_dict)
-        if is_main_process() and self.verbose:
+        if self.is_main() and self.verbose:
             self.old_lr = model.optimizer.state_dict()['param_groups'][0]['lr']
             print(
                 f"A l'initialisation le lr = {self.old_lr}\n",
@@ -1047,7 +1059,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                 self.scheduler.step(res_loss)
             else:
                 self.scheduler.step()
-            if is_main_process() and self.verbose:
+            if self.is_main() and self.verbose:
                 lr = model.optimizer.state_dict()['param_groups'][0]['lr']
                 if self.old_lr != lr:
                     print(
@@ -1072,7 +1084,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                 self.scheduler.step(res_loss)
             else:
                 self.scheduler.step()
-            if is_main_process() and self.verbose:
+            if self.is_main() and self.verbose:
                 lr = model.optimizer.state_dict()['param_groups'][0]['lr']
                 if self.old_lr != lr:
                     print(
@@ -1082,7 +1094,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
                         flush=True
                     )
                     self.old_lr = lr
-        if is_main_process() and self.path_backup:
+        if self.is_main() and self.path_backup:
             if state.n_iter % self.n_iter == 0:
                 pkl.dump(
                     self.scheduler.state_dict(),
@@ -1118,7 +1130,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.path_backup:
+        if self.is_main() and self.path_backup:
             if self.erase_folder:
                 files = list(
                     filter(
@@ -1142,7 +1154,7 @@ class LRSchedulerCallback(CallbackInterface, metaclass=SuperclassDocstring):
         exception: Exception,
         **kwargs
     ) -> None:
-        if is_main_process() and self.path_backup:
+        if self.is_main() and self.path_backup:
             if isinstance(exception, KeyboardInterrupt) and self.erase_folder:
                 files = list(
                     filter(
@@ -1177,6 +1189,10 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
     bar_eval: bool = False
     _swa_process: bool = False
 
+    def __post_init__(self):
+        from dstk.pytorch._utils_distrib import is_main_process
+        self.is_main = is_main_process
+
     def begin_epoch(
         self,
         model: PyTorchEstimators,
@@ -1186,7 +1202,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.bar_epoch:
+        if self.is_main() and self.bar_epoch:
             self.epoch_bar = tqdm(
                 total=state.epoch_max_steps,
                 desc=(
@@ -1208,7 +1224,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.bar_epoch:
+        if self.is_main() and self.bar_epoch:
             self.epoch_bar.refresh()
             self.epoch_bar.close()
 
@@ -1221,7 +1237,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.bar_epoch:
+        if self.is_main() and self.bar_epoch:
             self.epoch_bar.update(1)
 
     def begin_eval(
@@ -1233,7 +1249,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: None,
         **kwargs
     ) -> None:
-        if is_main_process() and self.bar_eval:
+        if self.is_main() and self.bar_eval:
             self.eval_bar = tqdm(
                 total=state.eval_max_steps,
                 desc="Evaluation",
@@ -1249,7 +1265,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.bar_eval:
+        if self.is_main() and self.bar_eval:
             self.epoch_bar.refresh()
             self.eval_bar.close()
 
@@ -1262,7 +1278,7 @@ class ProgressBarCallback(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process() and self.bar_eval:
+        if self.is_main() and self.bar_eval:
             self.eval_bar.update(1)
 
 
@@ -1301,6 +1317,8 @@ class Supervision(CallbackInterface, metaclass=SuperclassDocstring):
         flush_secs: int=120,
         filename_suffix: str=''
     ):
+        from dstk.pytorch._utils_distrib import is_main_process
+        self.is_main = is_main_process
         if is_main_process():
             try:
                 global SummaryWriter
@@ -1342,7 +1360,7 @@ class Supervision(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process():
+        if self.is_main():
             self.writer.add_scalar(
                 'Loss/train',
                 res_loss,
@@ -1363,12 +1381,6 @@ class Supervision(CallbackInterface, metaclass=SuperclassDocstring):
         res_loss: float,
         **kwargs
     ) -> None:
-        if is_main_process():
+        if self.is_main():
             self.writer.add_scalar('Loss/eval', res_loss, state.n_iter)
 
-
-DEFAULT_CALLBACKS = [
-    ProgressBarCallback(),
-    PrintCallback(),
-    EarlyStoppingCallback(verbose=True)
-]
