@@ -88,7 +88,7 @@ def init_distributed(dist_url: str = "env://", backend: str = "nccl"):
     return local_rank
 
 
-def overload_distributed_data_parallel(
+def _overload_distributed_data_parallel(
     model: Module,
     master_class: Optional[Callable] = None
 ):
@@ -165,6 +165,54 @@ def overload_distributed_data_parallel(
             )
 
 
+def overload_distributed_data_parallel(model: Module):
+    r"""
+    Fonction qui vien surchargé la classe
+    torch.nn.parallel.DistributedDataParallel afin de s'interfacer avec
+    les classes DSTK. Pour connaitre les arguements de cette classe ce
+    référer à la doc PyTorch.
+
+    Parameters
+    ----------
+    model: Module
+        Modèle PyTorch vania ou hérité des classes DSTK.
+    """
+    class DistributedDataParallel(DDP):
+        def __init__(
+            self,
+            module,
+            device_ids=None,
+            output_device=None,
+            dim=0,
+            broadcast_buffers=True,
+            process_group=None,
+            bucket_cap_mb=25,
+            find_unused_parameters=False,
+            check_reduction=False,
+            gradient_as_bucket_view=False,
+            static_graph=False,
+        ):
+            super().__init__(
+                module=module,
+                device_ids=device_ids,
+                output_device=output_device,
+                dim=dim,
+                broadcast_buffers=broadcast_buffers,
+                process_group=process_group,
+                bucket_cap_mb=bucket_cap_mb,
+                find_unused_parameters=find_unused_parameters,
+                check_reduction=check_reduction,
+                gradient_as_bucket_view=gradient_as_bucket_view,
+                static_graph=static_graph,
+            )
+    attr = list(filter(lambda x: not x.startswith('__'), dir(model)))
+    attr_ddp = list(filter(lambda x: not x.startswith('__'), dir(DDP)))
+    for ii in attr:
+        if not ii in attr_ddp:
+            setattr(DistributedDataParallel, ii, getattr(model, ii))
+    return DistributedDataParallel
+
+
 def auto_init_distributed(
     model: Module,
     train_dataset: Dataset,
@@ -239,7 +287,11 @@ def auto_init_distributed(
 
     model = model.cuda()
     model = SyncBatchNorm.convert_sync_batchnorm(model)
-    model = overload_distributed_data_parallel(model, master_class)(
+    # model = overload_distributed_data_parallel(model, master_class)(
+    #     module=model,
+    #     device_ids=[local_rank]
+    # )
+    model = overload_distributed_data_parallel(model)(
         module=model,
         device_ids=[local_rank]
     )
