@@ -2,7 +2,9 @@
 # -*- coding: utf-8 -*-
 
 from ._roc_analyser import ROCAnalyzer
+from ._bias_analyzer import BiasAnalyser
 
 __all__ = (
-    'ROCAnalyzer'
+    'ROCAnalyzer',
+    'BiasAnalyser'
 )
